@@ -2,12 +2,11 @@
 pub enum CleanerError {
     IOError(std::io::Error),
     GitError(git2::Error),
-    UnknownError
+    UnknownError,
 }
 
 pub type Result<T> = std::result::Result<T, CleanerError>;
 
-
 impl From<()> for CleanerError {
     fn from(_: ()) -> Self {
         Self::UnknownError
@@ -20,7 +19,6 @@ impl From<std::io::Error> for CleanerError {
     }
 }
 
-
 impl From<git2::Error> for CleanerError {
     fn from(e: git2::Error) -> Self {
         Self::GitError(e)
